@@ -103,7 +103,7 @@ USAGE
 puppet agent [--certname <NAME>] [-D|--daemonize|--no-daemonize]
   [-d|--debug] [--detailed-exitcodes] [--digest <DIGEST>] [--disable [MESSAGE]] [--enable]
   [--fingerprint] [-h|--help] [-l|--logdest syslog|eventlog|<ABS FILEPATH>|console]
-  [--masterport <PORT>] [--noop] [-o|--onetime] [--sourceaddress <IP_ADDRESS>] [-t|--test]
+  [--serverport <PORT>] [--noop] [-o|--onetime] [--sourceaddress <IP_ADDRESS>] [-t|--test]
   [-v|--verbose] [-V|--version] [-w|--waitforcert <SECONDS>]
 
 
@@ -277,8 +277,9 @@ generated by running puppet agent with '--genconfig'.
   format.
 
 * --masterport:
-  The port on which to contact the puppet master.
-  (This is a Puppet setting, and can go in puppet.conf.)
+  The port on which to contact the Puppet Server.
+  (This is a Puppet setting, and can go in puppet.conf.
+  Deprecated in favor of the 'serverport' setting.)
 
 * --noop:
   Use 'noop' mode where the daemon runs in a no-op or dry-run mode. This
@@ -294,6 +295,10 @@ generated by running puppet agent with '--genconfig'.
   (This is a Puppet setting, and can go in puppet.conf. Note the special 'no-'
   prefix for boolean settings on the command line.)
 
+* --serverport:
+  The port on which to contact the Puppet Server.
+  (This is a Puppet setting, and can go in puppet.conf.)
+
 * --sourceaddress:
   Set the source IP address for transactions. This defaults to automatically selected.
   (This is a Puppet setting, and can go in puppet.conf.)
