@@ -109,7 +109,8 @@ private
 
     # Check to see if this is a file argument and it has extra options
     begin
-      if value.is_a?(String) and options = extract_fileinfo(value)
+      options = extract_fileinfo(value) if value.is_a?(String)
+      if options
         section.with_setting(var, options[:value], Meta.new(options[:owner],
                                                             options[:group],
                                                             options[:mode]))
